Contributors — atomate 0.9.2 documentation

# Contributors

atomate development is led by the Hacking Materials research group led by Anubhav Jain at Lawrence Berkeley National Lab, using primarily research funding from U.S. Department of Energy Early Career program; additional support and funding is from the U.S. Department of Energy Materials Project program.

Contributions are provided by:

- Alireza Faghaninia, Alex Dunn, Alex Ganose, and Evan Spotte-Smith through the research group of A. Jain at LBNL.

- Kiran Mathew, Shyam Dwaraknath, Joey Montoya, Murat Aykol, Patrick Huck, Brandon Wood, Sam Blau, Jimmy Shen, Anne Rutt, Eric Sivonxay, and Martin Siron through the research group of Prof. Kristin Persson at UC Berkeley.

- Hanmei Tang, Prof. Shyue Ping Ong, and the Materials Virtual Lab research group at UC San Diego.

- Brandon Bocklund, who led the atomate documentation effort, through the research group of Prof. Zi-Kiu Liu at Penn State.

- Tess Smidt through the research group of Prof. Jeff Neaton at UC Berkeley.

- Danny Broberg through the research group of Prof. Mark Asta at UC Berkeley.

- External contributors: specter119, M. Dias Costa, S. Torrisi, Max Dylla, Marnik Bercx